<?php
/**
* 2007-2012 PrestaShop
*
* NOTICE OF LICENSE
*
* This source file is subject to the Academic Free License (AFL 3.0)
* that is bundled with this package in the file LICENSE.txt.
* It is also available through the world-wide-web at this URL:
* http://opensource.org/licenses/afl-3.0.php
* If you did not receive a copy of the license and are unable to
* obtain it through the world-wide-web, please send an email
* to license@prestashop.com so we can send you a copy immediately.
*
* DISCLAIMER
*
* Do not edit or add to this file if you wish to upgrade PrestaShop to newer
* versions in the future. If you wish to customize PrestaShop for your
* needs please refer to http://www.prestashop.com for more information.
*
*  @author PrestaShop SA <contact@prestashop.com>
*  @copyright  2007-2012 PrestaShop SA
*  @version  Release: $Revision: 17065 $
*  @license    http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
*  International Registered Trademark & Property of PrestaShop SA
*/

/**
 * @since 1.6.0
 * @version 1 (2015-01-27)
 */
 
if (!defined('_PS_VERSION_'))
  exit;

class AWS extends Module
{
	public function __construct()
	{
		$this->name = 'aws';
		$this->tab = 'administration';
		$this->version = 1.0;
		$this->author = 'ColumbusSoft';
		$this->need_instance = 1;
		$this->ps_versions_compliancy = array('min' => '1.6', 'max' => _PS_VERSION_); 
		$this->module_key='40f01399d66a86ffdcfe46e65715dd42';
		$this->bootstrap = true;
		
		$this->options = array(
			'aws_office_load_option'=> array('AWS_FRONT_OFFICE','AWS_BACK_OFFICE'),
			'aws_sdk_load_options'=> array(
				'aws_AutoScaling','aws_CloudFormation','aws_CloudFront','aws_CloudHsm',
				'aws_CloudSearch','aws_CloudSearchDomain','aws_CloudTrail','aws_CloudWatch',
				'aws_CloudWatchLogs','aws_CodeDeploy','aws_CognitoIdentity','aws_CognitoSync','aws_ConfigService',
				'aws_DataPipeline','aws_DirectConnect','aws_DynamoDb','aws_Ec2','aws_Ecs',
				'aws_ElastiCache','aws_ElasticBeanstalk','aws_ElasticLoadBalancing','aws_ElasticTranscoder','aws_Emr',
				'aws_Glacier','aws_Iam','aws_ImportExport','aws_Kinesis','aws_Kms',
				'aws_Lambda','aws_OpsWorks','aws_Rds','aws_Redshift','aws_Route53',
				'aws_Route53Domains','aws_S3','aws_Ses','aws_SimpleDb','aws_Sns',
				'aws_Sqs','aws_StorageGateway','aws_Sts','aws_Support','aws_Swf'
			)
		);
		parent::__construct();
		
		$this->displayName = $this->l('Amazon Web Services SDK Loader For PrestaShop');
		$this->description = $this->l('This module will allow you to load the AWS SDKs you need in your code, the idea is to prevent multiple AWS dependendent modules from conflicts in the future. Once Installed the aws-autoloader will be loaded in every prestashop page!'); 
		
		$this->confirmUninstall = $this->l('Are you sure you want to uninstall?');
		
		if (!Configuration::get('MYMODULE_NAME'))      
		  $this->warning = $this->l('No name provided');
	}
	
	public function install()
	{
	  if (Shop::isFeatureActive())
		Shop::setContext(Shop::CONTEXT_ALL);
	 
	  if (!parent::install() ) {
		return false;
	  }
	  
         
		foreach($this->options as $option_type) {
			foreach($option_type as $option) {
				$key = Tools::strtoupper($option);
				Configuration::updateValue($key,1);		
			}
		}
		
		$this->enable();
		
	  return true;
	}
	
	public function uninstall()
	{
	  if (!parent::uninstall() ||
		!Configuration::deleteByName('MYMODULE_NAME')
	  ) 
		return false;
		
		foreach($this->options as $option_type) {
			foreach($option_type as $option) {
				$key = Tools::strtoupper($option);
				Configuration::deleteByName($key,1);		
			}
		}
		Configuration::updateValue('AWS_COMMON', 0);
	 
	  return true;
	}
	
	public function disable($forceAll = false) 
	{
		Configuration::updateValue('AWS_COMMON', 0);
		parent::disable($forceAll);
	}
	
	public function enable($forceAll = false) 
	{
		Configuration::updateValue('AWS_COMMON', 1);
		parent::disable($forceAll);
	}
 
	
	
	public function getContent()
	{
		
		
		if (Tools::isSubmit('submitModule'))
		{
			foreach($this->options as $option_type) 
			{
				foreach($option_type as $option) 
				{
					$key = Tools::strtoupper($option);
					Configuration::updateValue($key,Tools::getvalue($key));		
				}
			}
			Configuration::updateValue('AWS_COMMON', 1);
			$this->displayConfirmation($this->l('Configuration updated'));
		}

		foreach($this->options as $option_type) 
		{
			foreach($option_type as $option) 
			{
				$key = Tools::strtoupper($option);
				$this->context->smarty->assign($key, Configuration::get($key));
			}
		}
			
		$this->context->smarty->assign('aws_sdk_load_options',$this->options['aws_sdk_load_options']);
		
		return $this->context->smarty->fetch(dirname(__FILE__).'/views/templates/admin/configuration.tpl');
		
	}
	 
}